pywws.Forecast — pywws 13.03_7f9fc90 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.03_7f9fc90 documentation »
- Python programs and modules »

# pywws.Forecast

Predict future weather using recent data

    usage: python RunModule.py Forecast [options] data_dir
    options are:
     -h | --help  display this help
    data_dir is the root directory of the weather data

Functions

`Zambretti`(params, hourly_data) |
`main`([argv]) |

`pywws.Forecast.` `ZambrettiCode`(params, hourly_data)

`pywws.Forecast.` `Zambretti`(params, hourly_data)

`pywws.Forecast.` `main`(argv=None)

### Navigation

- index
- modules |
- next |
- previous |
- pywws 13.03_7f9fc90 documentation »
- Python programs and modules »